API Reference
=============

.. toctree::
   :maxdepth: 2
   :caption: Contents:


Dichotomous variables
---------------------

correlation coefficients for dichotomous (binary) variables

.. autosummary::
   :toctree: generated
   :recursive:

   ordinalcorr.biserial
   ordinalcorr.point_biserial
   ordinalcorr.tetrachoric


Polytomous variables
--------------------

correlation coefficients for polytomous (ordered categorical) variables

.. autosummary::
   :toctree: generated
   :recursive:

   ordinalcorr.polychoric
   ordinalcorr.polyserial


Correlation Matrix
------------------

.. autosummary::
   :toctree: generated
   :recursive:

   ordinalcorr.hetcor
